@@ -12,7 +12,7 @@ from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.enum_types import (DwfAnalogInTriggerLengthCondition, DwfTriggerSource,
                                              DwfAnalogInTriggerType, DwfTriggerSlope, DwfAnalogInFilter,
                                              DwfAcquisitionMode, DwfState)
-from pydwf.core.auxiliary.constants import RESULT_SUCCESS
+from pydwf.core.auxiliary.constants  import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
 
 
@@ -443,7 +443,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     def bitsInfo(self) -> int:
         """Get the fixed the number of bits used by the |AnalogIn| ADC.
 
-        This number of bits can only be queried; it cannot be changed.
+        The number of bits can only be queried; it cannot be changed.
 
         Note:
             The Analog Discovery 2 uses an |Analog Devices AD9648| two-channel ADC. It converts 14-bit samples at a rate
@@ -753,17 +753,17 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def channelEnableSet(self, channel_index: int, enable: bool) -> None:
+    def channelEnableSet(self, channel_index: int, channel_enable: bool) -> None:
         """Enable or disable the specified |AnalogIn| input channel.
 
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
-            enable: bool: Whether to enable (True) or disable (False) the specified channel.
+            channel_enable: bool: Whether to enable (True) or disable (False) the specified channel.
 
         Raises:
             DwfLibraryError: An error occurred while enabling or disabling the channel.
         """
-        result = self.lib.FDwfAnalogInChannelEnableSet(self.hdwf, channel_index, enable)
+        result = self.lib.FDwfAnalogInChannelEnableSet(self.hdwf, channel_index, channel_enable)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -779,12 +779,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the enabled/disabled state of the channel.
         """
-        c_enable = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInChannelEnableGet(self.hdwf, channel_index, c_enable)
+        c_channel_enable = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInChannelEnableGet(self.hdwf, channel_index, c_channel_enable)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        enable = bool(c_enable.value)
-        return enable
+        channel_enable = bool(c_channel_enable.value)
+        return channel_enable
 
     def channelFilterInfo(self) -> List[DwfAnalogInFilter]:
         """Get a list of valid |AnalogIn| channel filter settings.
@@ -1390,39 +1390,39 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger holdoff info.
         """
-        c_trigger_holdoff_min = typespec_ctypes.c_double()
-        c_trigger_holdoff_max = typespec_ctypes.c_double()
-        c_trigger_holdoff_num_steps = typespec_ctypes.c_double()
+        c_trigger_detector_holdoff_min = typespec_ctypes.c_double()
+        c_trigger_detector_holdoff_max = typespec_ctypes.c_double()
+        c_trigger_detector_holdoff_num_steps = typespec_ctypes.c_double()
 
         result = self.lib.FDwfAnalogInTriggerHoldOffInfo(
             self.hdwf,
-            c_trigger_holdoff_min,
-            c_trigger_holdoff_max,
-            c_trigger_holdoff_num_steps)
+            c_trigger_detector_holdoff_min,
+            c_trigger_detector_holdoff_max,
+            c_trigger_detector_holdoff_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_trigger_holdoff_num_steps.value.is_integer():
-            raise PyDwfError("Bad c_trigger_holdoff_num_steps value.")
+        if not c_trigger_detector_holdoff_num_steps.value.is_integer():
+            raise PyDwfError("Bad c_trigger_detector_holdoff_num_steps value.")
 
-        trigger_holdoff_min = c_trigger_holdoff_min.value
-        trigger_holdoff_max = c_trigger_holdoff_max.value
-        trigger_holdoff_num_steps = int(c_trigger_holdoff_num_steps.value)
+        trigger_detector_holdoff_min = c_trigger_detector_holdoff_min.value
+        trigger_detector_holdoff_max = c_trigger_detector_holdoff_max.value
+        trigger_detector_holdoff_num_steps = int(c_trigger_detector_holdoff_num_steps.value)
 
-        return (trigger_holdoff_min, trigger_holdoff_max, trigger_holdoff_num_steps)
+        return (trigger_detector_holdoff_min, trigger_detector_holdoff_max, trigger_detector_holdoff_num_steps)
 
-    def triggerHoldOffSet(self, trigger_holdoff: float) -> None:
+    def triggerHoldOffSet(self, trigger_detector_holdoff: float) -> None:
         """Set the |AnalogIn| trigger detector holdoff value, in seconds.
 
         Parameters:
-            trigger_holdoff (float): The trigger holdoff setting, in seconds.
+            trigger_detector_holdoff (float): The trigger holdoff setting, in seconds.
 
         The value 0 disables the trigger detector holdoff feature.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger detector holdoff value.
         """
-        result = self.lib.FDwfAnalogInTriggerHoldOffSet(self.hdwf, trigger_holdoff)
+        result = self.lib.FDwfAnalogInTriggerHoldOffSet(self.hdwf, trigger_detector_holdoff)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1435,12 +1435,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger holdoff value.
         """
-        c_trigger_holdoff = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInTriggerHoldOffGet(self.hdwf, c_trigger_holdoff)
+        c_trigger_detector_holdoff = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInTriggerHoldOffGet(self.hdwf, c_trigger_detector_holdoff)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_holdoff = c_trigger_holdoff.value
-        return trigger_holdoff
+        trigger_detector_holdoff = c_trigger_detector_holdoff.value
+        return trigger_detector_holdoff
 
     def triggerTypeInfo(self) -> List[DwfAnalogInTriggerType]:
         """Get the valid |AnalogIn| trigger detector trigger-type values.
@@ -1454,25 +1454,25 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector trigger-type info.
         """
-        c_trigger_type_bitset = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInTriggerTypeInfo(self.hdwf, c_trigger_type_bitset)
+        c_trigger_detector_type_bitset = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInTriggerTypeInfo(self.hdwf, c_trigger_detector_type_bitset)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_type_bitset = c_trigger_type_bitset.value
-        trigger_type_list = [trigger_type for trigger_type in DwfAnalogInTriggerType
-                             if trigger_type_bitset & (1 << trigger_type.value)]
-        return trigger_type_list
+        trigger_detector_type_bitset = c_trigger_detector_type_bitset.value
+        trigger_detector_type_list = [trigger_detector_type for trigger_detector_type in DwfAnalogInTriggerType
+                             if trigger_detector_type_bitset & (1 << trigger_detector_type.value)]
+        return trigger_detector_type_list
 
-    def triggerTypeSet(self, trigger_type: DwfAnalogInTriggerType) -> None:
+    def triggerTypeSet(self, trigger_detector_type: DwfAnalogInTriggerType) -> None:
         """Set the |AnalogIn| trigger detector trigger-type.
 
         Parameters:
-            trigger_type (DwfAnalogInTriggerType): The trigger detector trigger-type to be configured.
+            trigger_detector_type (DwfAnalogInTriggerType): The trigger detector trigger-type to be configured.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger detector trigger-type.
         """
-        result = self.lib.FDwfAnalogInTriggerTypeSet(self.hdwf, trigger_type.value)
+        result = self.lib.FDwfAnalogInTriggerTypeSet(self.hdwf, trigger_detector_type.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1485,12 +1485,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector trigger-type.
         """
-        c_trigger_type = typespec_ctypes.DwfAnalogInTriggerType()
-        result = self.lib.FDwfAnalogInTriggerTypeGet(self.hdwf, c_trigger_type)
+        c_trigger_detector_type = typespec_ctypes.DwfAnalogInTriggerType()
+        result = self.lib.FDwfAnalogInTriggerTypeGet(self.hdwf, c_trigger_detector_type)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_type = DwfAnalogInTriggerType(c_trigger_type.value)
-        return trigger_type
+        trigger_detector_type = DwfAnalogInTriggerType(c_trigger_detector_type.value)
+        return trigger_detector_type
 
     def triggerChannelInfo(self) -> Tuple[int, int]:
         """Get the |AnalogIn| trigger detector channel range.
@@ -1505,30 +1505,30 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector channel range.
         """
-        c_trigger_channel_index_min = typespec_ctypes.c_int()
-        c_trigger_channel_index_max = typespec_ctypes.c_int()
+        c_trigger_detector_channel_index_min = typespec_ctypes.c_int()
+        c_trigger_detector_channel_index_max = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogInTriggerChannelInfo(
             self.hdwf,
-            c_trigger_channel_index_min,
-            c_trigger_channel_index_max)
+            c_trigger_detector_channel_index_min,
+            c_trigger_detector_channel_index_max)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_channel_index_min = c_trigger_channel_index_min.value
-        trigger_channel_index_max = c_trigger_channel_index_max.value
-        return (trigger_channel_index_min, trigger_channel_index_max)
+        trigger_detector_channel_index_min = c_trigger_detector_channel_index_min.value
+        trigger_detector_channel_index_max = c_trigger_detector_channel_index_max.value
+        return (trigger_detector_channel_index_min, trigger_detector_channel_index_max)
 
-    def triggerChannelSet(self, trigger_channel_index: int) -> None:
+    def triggerChannelSet(self, trigger_detector_channel_index: int) -> None:
         """Set the |AnalogIn| trigger detector channel.
 
         This is the analog input channel that the |AnalogIn| trigger detector monitors for trigger events.
 
         Parameters:
-            trigger_channel_index (int): The trigger detector channel to be selected.
+            trigger_detector_channel_index (int): The trigger detector channel to be selected.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger detector channel.
         """
-        result = self.lib.FDwfAnalogInTriggerChannelSet(self.hdwf, trigger_channel_index)
+        result = self.lib.FDwfAnalogInTriggerChannelSet(self.hdwf, trigger_detector_channel_index)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1543,12 +1543,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector channel.
         """
-        c_trigger_channel_index = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInTriggerChannelGet(self.hdwf, c_trigger_channel_index)
+        c_trigger_detector_channel_index = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInTriggerChannelGet(self.hdwf, c_trigger_detector_channel_index)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_channel_index = c_trigger_channel_index.value
-        return trigger_channel_index
+        trigger_detector_channel_index = c_trigger_detector_channel_index.value
+        return trigger_detector_channel_index
 
     def triggerFilterInfo(self) -> List[DwfAnalogInFilter]:
         """Get a list of valid |AnalogIn| trigger detector filter values.
@@ -1559,25 +1559,25 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the valid trigger detector channel filter values.
         """
-        c_trigger_filter_bitset = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInTriggerFilterInfo(self.hdwf, c_trigger_filter_bitset)
+        c_trigger_detector_filter_bitset = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInTriggerFilterInfo(self.hdwf, c_trigger_detector_filter_bitset)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_filter_bitset = c_trigger_filter_bitset.value
-        trigger_filter_list = [trigger_filter for trigger_filter in DwfAnalogInFilter
-                               if trigger_filter_bitset & (1 << trigger_filter.value)]
-        return trigger_filter_list
+        trigger_detector_filter_bitset = c_trigger_detector_filter_bitset.value
+        trigger_detector_filter_list = [trigger_detector_filter for trigger_detector_filter in DwfAnalogInFilter
+                               if trigger_detector_filter_bitset & (1 << trigger_detector_filter.value)]
+        return trigger_detector_filter_list
 
-    def triggerFilterSet(self, trigger_filter: DwfAnalogInFilter) -> None:
+    def triggerFilterSet(self, trigger_detector_filter: DwfAnalogInFilter) -> None:
         """Set the |AnalogIn| trigger detector channel filter.
 
         Parameters:
-            trigger_filter (DwfAnalogInFilter): The trigger detector channel filter to be selected.
+            trigger_detector_filter (DwfAnalogInFilter): The trigger detector channel filter to be selected.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger detector channel filter.
         """
-        result = self.lib.FDwfAnalogInTriggerFilterSet(self.hdwf, trigger_filter.value)
+        result = self.lib.FDwfAnalogInTriggerFilterSet(self.hdwf, trigger_detector_filter.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1590,12 +1590,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector channel filter.
         """
-        c_trigger_filter = typespec_ctypes.DwfAnalogInFilter()
-        result = self.lib.FDwfAnalogInTriggerFilterGet(self.hdwf, c_trigger_filter)
+        c_trigger_detector_filter = typespec_ctypes.DwfAnalogInFilter()
+        result = self.lib.FDwfAnalogInTriggerFilterGet(self.hdwf, c_trigger_detector_filter)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_filter = DwfAnalogInFilter(c_trigger_filter.value)
-        return trigger_filter
+        trigger_detector_filter = DwfAnalogInFilter(c_trigger_detector_filter.value)
+        return trigger_detector_filter
 
     def triggerLevelInfo(self) -> Tuple[float, float, int]:
         """Get the |AnalogIn| trigger detector valid trigger level range, in Volts.
@@ -1607,28 +1607,28 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger level range.
         """
-        c_trigger_level_min = typespec_ctypes.c_double()
-        c_trigger_level_max = typespec_ctypes.c_double()
-        c_trigger_level_num_steps = typespec_ctypes.c_double()
+        c_trigger_detector_level_min = typespec_ctypes.c_double()
+        c_trigger_detector_level_max = typespec_ctypes.c_double()
+        c_trigger_detector_level_num_steps = typespec_ctypes.c_double()
 
         result = self.lib.FDwfAnalogInTriggerLevelInfo(
             self.hdwf,
-            c_trigger_level_min,
-            c_trigger_level_max,
-            c_trigger_level_num_steps)
+            c_trigger_detector_level_min,
+            c_trigger_detector_level_max,
+            c_trigger_detector_level_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_trigger_level_num_steps.value.is_integer():
-            raise PyDwfError("Bad c_trigger_level_num_steps value")
+        if not c_trigger_detector_level_num_steps.value.is_integer():
+            raise PyDwfError("Bad c_trigger_detector_level_num_steps value")
 
-        trigger_level_min = c_trigger_level_min.value
-        trigger_level_max = c_trigger_level_max.value
-        trigger_level_num_steps = int(c_trigger_level_num_steps.value)
+        trigger_detector_level_min = c_trigger_detector_level_min.value
+        trigger_detector_level_max = c_trigger_detector_level_max.value
+        trigger_detector_level_num_steps = int(c_trigger_detector_level_num_steps.value)
 
-        return (trigger_level_min, trigger_level_max, trigger_level_num_steps)
+        return (trigger_detector_level_min, trigger_detector_level_max, trigger_detector_level_num_steps)
 
-    def triggerLevelSet(self, trigger_level: float) -> None:
+    def triggerLevelSet(self, trigger_detector_level: float) -> None:
         """Set the |AnalogIn| trigger detector trigger-level, in Volts.
 
         Parameters:
@@ -1637,7 +1637,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while setting the trigger level.
         """
-        result = self.lib.FDwfAnalogInTriggerLevelSet(self.hdwf, trigger_level)
+        result = self.lib.FDwfAnalogInTriggerLevelSet(self.hdwf, trigger_detector_level)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1650,12 +1650,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger level.
         """
-        c_trigger_level = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInTriggerLevelGet(self.hdwf, c_trigger_level)
+        c_trigger_detector_level = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInTriggerLevelGet(self.hdwf, c_trigger_detector_level)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_level = c_trigger_level.value
-        return trigger_level
+        trigger_detector_level = c_trigger_detector_level.value
+        return trigger_detector_level
 
     def triggerHysteresisInfo(self) -> Tuple[float, float, int]:
         """Get the |AnalogIn| trigger detector valid hysteresis range, in Volts.
@@ -1668,37 +1668,37 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger hysteresis info.
         """
-        c_trigger_hysteresis_min = typespec_ctypes.c_double()
-        c_trigger_hysteresis_max = typespec_ctypes.c_double()
-        c_trigger_hysteresis_num_steps = typespec_ctypes.c_double()
+        c_trigger_detector_hysteresis_min = typespec_ctypes.c_double()
+        c_trigger_detector_hysteresis_max = typespec_ctypes.c_double()
+        c_trigger_detector_hysteresis_num_steps = typespec_ctypes.c_double()
 
         result = self.lib.FDwfAnalogInTriggerHysteresisInfo(
             self.hdwf,
-            c_trigger_hysteresis_min,
-            c_trigger_hysteresis_max,
-            c_trigger_hysteresis_num_steps)
+            c_trigger_detector_hysteresis_min,
+            c_trigger_detector_hysteresis_max,
+            c_trigger_detector_hysteresis_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_trigger_hysteresis_num_steps.value.is_integer():
-            raise PyDwfError("Bad c_trigger_hysteresis_num_steps value.")
+        if not c_trigger_detector_hysteresis_num_steps.value.is_integer():
+            raise PyDwfError("Bad c_trigger_detector_hysteresis_num_steps value.")
 
-        trigger_hysteresis_min = c_trigger_hysteresis_min.value
-        trigger_hysteresis_max = c_trigger_hysteresis_max.value
-        trigger_hysteresis_num_steps = int(c_trigger_hysteresis_num_steps.value)
+        trigger_detector_hysteresis_min = c_trigger_detector_hysteresis_min.value
+        trigger_detector_hysteresis_max = c_trigger_detector_hysteresis_max.value
+        trigger_detector_hysteresis_num_steps = int(c_trigger_detector_hysteresis_num_steps.value)
 
-        return (trigger_hysteresis_min, trigger_hysteresis_max, trigger_hysteresis_num_steps)
+        return (trigger_detector_hysteresis_min, trigger_detector_hysteresis_max, trigger_detector_hysteresis_num_steps)
 
-    def triggerHysteresisSet(self, trigger_hysteresis: float) -> None:
+    def triggerHysteresisSet(self, trigger_detector_hysteresis: float) -> None:
         """Set the |AnalogIn| trigger detector hysteresis, in Volts.
 
         Parameters:
-            trigger_hysteresis (float): The trigger hysteresis to be configured, in Volts.
+            trigger_detector_hysteresis (float): The trigger hysteresis to be configured, in Volts.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger hysteresis.
         """
-        result = self.lib.FDwfAnalogInTriggerHysteresisSet(self.hdwf, trigger_hysteresis)
+        result = self.lib.FDwfAnalogInTriggerHysteresisSet(self.hdwf, trigger_detector_hysteresis)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1711,12 +1711,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger hysteresis.
         """
-        c_trigger_hysteresis = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInTriggerHysteresisGet(self.hdwf, c_trigger_hysteresis)
+        c_trigger_detector_hysteresis = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInTriggerHysteresisGet(self.hdwf, c_trigger_detector_hysteresis)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_hysteresis = c_trigger_hysteresis.value
-        return trigger_hysteresis
+        trigger_detector_hysteresis = c_trigger_detector_hysteresis.value
+        return trigger_detector_hysteresis
 
     def triggerConditionInfo(self) -> List[DwfTriggerSlope]:
         """Get the valid |AnalogIn| trigger detector condition (slope) options.
@@ -1727,27 +1727,27 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the valid trigger detector condition values.
         """
-        c_trigger_condition_bitset = typespec_ctypes.c_int()
+        c_trigger_detector_condition_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogInTriggerConditionInfo(
             self.hdwf,
-            c_trigger_condition_bitset)
+            c_trigger_detector_condition_bitset)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_condition_bitset = c_trigger_condition_bitset.value
-        trigger_condition_list = [trigger_condition for trigger_condition in DwfTriggerSlope
-                                  if trigger_condition_bitset & (1 << trigger_condition.value)]
-        return trigger_condition_list
+        trigger_detector_condition_bitset = c_trigger_detector_condition_bitset.value
+        trigger_detector_condition_list = [trigger_detector_condition for trigger_detector_condition in DwfTriggerSlope
+                                  if trigger_detector_condition_bitset & (1 << trigger_detector_condition.value)]
+        return trigger_detector_condition_list
 
-    def triggerConditionSet(self, trigger_condition: DwfTriggerSlope) -> None:
+    def triggerConditionSet(self, trigger_detector_condition: DwfTriggerSlope) -> None:
         """Set the |AnalogIn| trigger detector condition (slope).
 
         Parameters:
-            trigger_condition (DwfTriggerSlope): The trigger detector condition (slope) to be configured.
+            trigger_detector_condition (DwfTriggerSlope): The trigger detector condition (slope) to be configured.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger condition.
         """
-        result = self.lib.FDwfAnalogInTriggerConditionSet(self.hdwf, trigger_condition.value)
+        result = self.lib.FDwfAnalogInTriggerConditionSet(self.hdwf, trigger_detector_condition.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1760,12 +1760,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while setting the trigger condition (slope).
         """
-        c_trigger_condition = typespec_ctypes.DwfTriggerSlope()
-        result = self.lib.FDwfAnalogInTriggerConditionGet(self.hdwf, c_trigger_condition)
+        c_trigger_detector_condition = typespec_ctypes.DwfTriggerSlope()
+        result = self.lib.FDwfAnalogInTriggerConditionGet(self.hdwf, c_trigger_detector_condition)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_condition = c_trigger_condition.value
-        return DwfTriggerSlope(trigger_condition)
+        trigger_detector_condition = DwfTriggerSlope(c_trigger_detector_condition.value)
+        return trigger_detector_condition
 
     def triggerLengthInfo(self) -> Tuple[float, float, int]:
         """Get the valid |AnalogIn| trigger detector length range, in seconds.
@@ -1778,37 +1778,37 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger length range.
         """
-        c_trigger_length_min = typespec_ctypes.c_double()
-        c_trigger_length_max = typespec_ctypes.c_double()
-        c_trigger_length_num_steps = typespec_ctypes.c_double()
+        c_trigger_detector_length_min = typespec_ctypes.c_double()
+        c_trigger_detector_length_max = typespec_ctypes.c_double()
+        c_trigger_detector_length_num_steps = typespec_ctypes.c_double()
 
         result = self.lib.FDwfAnalogInTriggerLengthInfo(
             self.hdwf,
-            c_trigger_length_min,
-            c_trigger_length_max,
-            c_trigger_length_num_steps)
+            c_trigger_detector_length_min,
+            c_trigger_detector_length_max,
+            c_trigger_detector_length_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_trigger_length_num_steps.value.is_integer():
-            raise PyDwfError("Bad c_trigger_length_num_steps value.")
+        if not c_trigger_detector_length_num_steps.value.is_integer():
+            raise PyDwfError("Bad c_trigger_detector_length_num_steps value.")
 
-        trigger_length_min = c_trigger_length_min.value
-        trigger_length_max = c_trigger_length_max.value
-        trigger_length_num_steps = int(c_trigger_length_num_steps.value)
+        trigger_detector_length_min = c_trigger_detector_length_min.value
+        trigger_detector_length_max = c_trigger_detector_length_max.value
+        trigger_detector_length_num_steps = int(c_trigger_detector_length_num_steps.value)
 
-        return (trigger_length_min, trigger_length_max, trigger_length_num_steps)
+        return (trigger_detector_length_min, trigger_detector_length_max, trigger_detector_length_num_steps)
 
-    def triggerLengthSet(self, trigger_length: float) -> None:
+    def triggerLengthSet(self, trigger_detector_length: float) -> None:
         """Set the |AnalogIn| trigger detector length, in seconds.
 
         Parameters:
-            trigger_length (float): The trigger detector length to be configured, in seconds.
+            trigger_detector_length (float): The trigger detector trigger length to be configured, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger detector length.
         """
-        result = self.lib.FDwfAnalogInTriggerLengthSet(self.hdwf, trigger_length)
+        result = self.lib.FDwfAnalogInTriggerLengthSet(self.hdwf, trigger_detector_length)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1816,7 +1816,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         """Get the |AnalogIn| trigger detector length, in seconds.
 
         Returns:
-            float: The currently configured trigger detector length, in seconds.
+            float: The currently configured trigger detector trigger length, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector length.
@@ -1847,11 +1847,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         tlc_list = [tlc for tlc in DwfAnalogInTriggerLengthCondition if tlc_bitset & (1 << tlc.value)]
         return tlc_list
 
-    def triggerLengthConditionSet(self, trigger_length_condition: DwfAnalogInTriggerLengthCondition) -> None:
+    def triggerLengthConditionSet(self, trigger_detector_length_condition: DwfAnalogInTriggerLengthCondition) -> None:
         """Set the |AnalogIn| trigger detector length condition.
 
         Parameters:
-            trigger_length_condition (DwfAnalogInTriggerLengthCondition):
+            trigger_detector_length_condition (DwfAnalogInTriggerLengthCondition):
                 The trigger detector length condition to be configured.
 
         Raises:
@@ -1859,7 +1859,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         """
         result = self.lib.FDwfAnalogInTriggerLengthConditionSet(
             self.hdwf,
-            trigger_length_condition.value)
+            trigger_detector_length_condition.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
@@ -1872,14 +1872,14 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector length condition.
         """
-        c_trigger_length_condition = typespec_ctypes.DwfAnalogInTriggerLengthCondition()
+        c_trigger_detector_length_condition = typespec_ctypes.DwfAnalogInTriggerLengthCondition()
         result = self.lib.FDwfAnalogInTriggerLengthConditionGet(
             self.hdwf,
-            c_trigger_length_condition)
+            c_trigger_detector_length_condition)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_length_condition = DwfAnalogInTriggerLengthCondition(c_trigger_length_condition.value)
-        return trigger_length_condition
+        trigger_detector_length_condition = DwfAnalogInTriggerLengthCondition(c_trigger_detector_length_condition.value)
+        return trigger_detector_length_condition
 
     ####################################################################################################################
     #                                                                                                                  #
