@@ -649,11 +649,18 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def customAMFMEnableSet(self, channel_index: int, enable: bool) -> None:
+
+        # pylint: disable=line-too-long
+
         """Set the |AnalogOut| channel custom AM/FM enable status.
 
         Todo:
             Understand and document what this setting does.
 
+        Note:
+            This setting is only applicable to |Electronics Explorer:link| devices, as stated in a `message on the Digilent forum
+            <https://forum.digilentinc.com/topic/22281-installation-of-waveforms-on-linux-amd64-runs-into-dependency-problem/#comment-64663>`_.
+
         Parameters:
             channel_index (int): The |AnalogOut| channel.
             enable (bool): The custom AM/FM enable setting.
@@ -666,11 +673,18 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def customAMFMEnableGet(self, channel_index: int) -> bool:
+
+        # pylint: disable=line-too-long
+
         """Get the |AnalogOut| channel custom AM/FM enable status.
 
         Todo:
             Understand and document what this setting does.
 
+        Note:
+            This setting is only applicable to |Electronics Explorer:link| devices, as stated in a `message on the Digilent forum
+            <https://forum.digilentinc.com/topic/22281-installation-of-waveforms-on-linux-amd64-runs-into-dependency-problem/#comment-64663>`_.
+
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
@@ -1735,7 +1749,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
 
     ####################################################################################################################
     #                                                                                                                  #
-    #                                          CARRIER DATA MANAGEMENT (OBSOLETE)                                      #
+    #                                       CARRIER NODE DATA MANAGEMENT (OBSOLETE)                                    #
     #                                                                                                                  #
     ####################################################################################################################
 
