@@ -51,12 +51,106 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         device_count = c_device_count.value
         return device_count
 
+    def enumerateStart(self, enum_filter: Optional[DwfEnumFilter] = None) -> None:
+        """Start device enumeration.
+
+        Note:
+            This method is non-blocking (i.e., fast).
+
+        Note:
+            This method was added in DWF version 3.17.
+
+        Parameters:
+            enum_filter (Optional[DwfEnumFilter]): Specify which devices to enumerate.
+                If None, enumerate all devices.
+
+        Returns:
+            int: The number of Digilent Waveforms devices detected.
+
+        Raises:
+            DwfLibraryError: The Digilent Waveforms devices cannot be enumerated.
+        """
+        if enum_filter is None:
+            enum_filter = DwfEnumFilter.All
+
+        result = self.lib.FDwfEnumStart(enum_filter.value)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def enumerateStop(self) -> int:
+        """Stop device enumeration.
+
+        This should be called after a preceding :py:meth:`enumerateStart` invocation.
+
+        A :py:meth:`enumerateStart` call followed by a :py:meth:`enumerateStop` call essentially performs the same
+        function as a single :py:meth:`enumerateDevices` call, and takes approximately the same amount of time.
+
+        The advantage of using the Start/Stop methods is that the application can do useful work while the devices
+        are being enumerated in a background thread.
+
+        Note:
+            This method can take several seconds to complete.
+
+        Note:
+            This method was added in DWF version 3.17.
+
+        Returns:
+            int: The number of Digilent Waveforms devices detected.
+
+        Raises:
+            DwfLibraryError: The Digilent Waveforms devices cannot be enumerated.
+        """
+
+        c_device_count = typespec_ctypes.c_int()
+        result = self.lib.FDwfEnumStop(c_device_count)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+        device_count = c_device_count.value
+        return device_count
+
+    def enumerateInfo(self, device_index: int, options: str) -> None:
+
+        # pylint: disable=line-too-long
+
+        """Get info of the current device.
+
+        It is not clear what this method does; the underlying DWF *FDwfEnumInfo* function is missing from the
+        documentation.
+
+        An inquiry about this was made on the Digilent forum but the
+        `reply <https://forum.digilentinc.com/topic/22281-installation-of-waveforms-on-linux-amd64-runs-into-dependency-problem/#comment-64663>`_
+        did not go into sufficient detail on the functionality provided.
+
+        Parameters:
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
+                (see the :py:meth:`enumerateDevices` method).
+
+            options (str): The function or format of this parameter is not known.
+
+        Todo:
+            Figure out what this method does.
+
+        Note:
+            This method was added in DWF version 3.17.
+
+        Raises:
+            DwfLibraryError: The operation could not be performed.
+        """
+
+        options_arg = options.encode()
+
+        result = self.lib.FDwfEnumInfo(device_index, options_arg)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+
     def deviceType(self, device_index: int) -> Tuple[int, int]:
         """Return the device ID and version (hardware revision) of the selected Digilent Waveforms device.
 
         Note:
             This method returns the integer values as reported by the 'FDwfEnumDeviceType()' function
-            and does not cast them to |DwfDeviceID:link| and |DwfDeviceVersion:link| enumeration types.
+            and does not cast them to the |DwfDeviceID:link| and |DwfDeviceVersion:link| enumeration types.
 
             This is done to prevent unknown devices from raising an exception.
 
@@ -168,7 +262,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         if serial.startswith("SN:"):
             # The serial number is usually prefixed with the three-character string "SN:".
             # The only exception is the serial number of the Analog Discovery Pro devices,
-            # when enumerated from the device itself (in Linux mode).
+            # when enumerated on the device itself (as an AXI device in Linux mode).
             serial = serial[3:]
         if len(serial) != 12:
             raise PyDwfError("Serial number isn't 12 characters: {!r}".format(serial))
