@@ -86,9 +86,9 @@ class DigitalCan(AbstractDwfDeviceSubApi):
         """Transmit outgoing CAN bus data.
 
         Parameters:
-            v_id (int): (to be documented)
-            extended (bool): (to be documented)
-            remote (bool): (to be documented)
+            v_id (int): (to be documented).
+            extended (bool): (to be documented).
+            remote (bool): (to be documented).
             data (bytes): The data to be transmitted. Should be at most 8 bytes.
 
         Raises:
@@ -98,11 +98,11 @@ class DigitalCan(AbstractDwfDeviceSubApi):
         if len(data) > 8:
             raise PyDwfError("CAN message too long.")
 
-        # This will be flagged as an error by MyPy.
-        #
-        # See: https://github.com/sidneycadot/pydwf/issues/10
-        #      https://stackoverflow.com/questions/67692907
-        data_as_uchar_ptr = ctypes.cast(data, typespec_ctypes.c_unsigned_char_ptr)
+        # We convert the 'bytes' input data to an array of ctypes unsigned chars.
+        # This silences a spurious mypy warning.
+
+        data_ctypes_array_type = (ctypes.c_ubyte * len(data))
+        data_ctypes = data_ctypes_array_type(*data)
 
         result = self.lib.FDwfDigitalCanTx(
                 self.hdwf,
@@ -110,7 +110,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
                 extended,
                 remote,
                 len(data),
-                data_as_uchar_ptr
+                data_ctypes
             )
 
         if result != RESULT_SUCCESS:
