@@ -72,6 +72,8 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             data_rate (float): I²C data rate. Often-encountered rates are 100 kHz and 400 kHz, but many
                 modern I²C devices support higher data rates. Check the datasheet of your device.
 
+                The default value is 100 kHz.
+
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
@@ -79,6 +81,19 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
+    def timeoutSet(self, timeout: float) -> None:
+        """Set the I²C timeout, in seconds.
+
+        Parameters:
+            timeout (float): I²C timeout. The default value is 1 second.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfDigitalI2cTimeoutSet(self.hdwf, timeout)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
     def readNakSet(self, nak_last_read_byte: int) -> None:
         """Set read NAK state.
 
@@ -250,3 +265,41 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         nak = c_nak.value
 
         return nak
+
+    def spyStart(self) -> None:
+        """Start I²C spy.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfDigitalI2cSpyStart(self.hdwf)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def spyStatus(self, max_data_size: int) -> Tuple[int, int, List[int], int]:
+        """Get I²C spy status.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+
+        c_nak   = typespec_ctypes.c_int()
+        c_start = typespec_ctypes.c_int()
+        c_stop  = typespec_ctypes.c_int()
+
+        buffer_type = typespec_ctypes.c_unsigned_char * max_data_size
+        c_data = buffer_type()
+
+        c_data_size = typespec_ctypes.c_int(max_data_size)
+
+        result = self.lib.FDwfDigitalI2cSpyStatus(self.hdwf, c_start, c_stop, c_data, c_data_size, c_nak)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+        start = c_start.value
+        stop  = c_stop.value
+        nak   = c_nak.value
+
+        data_list = list(c_data)[:c_data_size.value]  # Only return the first 'c_data_size' words.
+
+        return (start, stop, data_list, nak)
