@@ -1,5 +1,6 @@
 """The |pydwf.core.api.digital_out| module implements a single class: |DigitalOut|."""
 
+import ctypes
 from typing import Tuple, List
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -839,6 +840,9 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     def dataSet(self, channel_index: int, bits: str, tristate: bool = False) -> None:
         """Set the |DigitalOut| arbitrary output data.
 
+        This function also sets the counter initial, low and high value, according to the
+        number of bits. The data-bits are sent out in LSB-first order.
+
         Parameters:
             channel_index (int): the channel for which to set the output data.
             bits (str): The bits, as a string.
@@ -851,7 +855,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         if tristate:
             bits = bits.replace('1', '11').replace('0', '01').replace('Z', '00')
 
-        countOfBits = len(bits)
+        # For tristate output, the count of bits is the total number of output values (I/O)
+        # and output enable (OE) bits, which should be an even number.
+
+        count_of_bits = len(bits)
 
         octets = []
         while len(bits) > 0:
@@ -862,24 +869,47 @@ class DigitalOut(AbstractDwfDeviceSubApi):
 
         octets_as_bytes = bytes(octets)
 
-        result = self.lib.FDwfDigitalOutDataSet(self.hdwf, channel_index, octets_as_bytes, countOfBits)
+        result = self.lib.FDwfDigitalOutDataSet(self.hdwf, channel_index, octets_as_bytes, count_of_bits)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def playDataSet(self, rg_bits: int, bits_per_sample: int, count_of_samples: int) -> None:
+    def playDataSet(self, bits: str, bits_per_sample: int, count_of_samples: int) -> None:
         """Set the |DigitalOut| playback data.
 
+        The output can be PushPull, OpenDrain, or OpenSource. Threestate data is not supported.
+
+        Note:
+            The DWF documentation explicitly states that this function is supported by the Digital Discovery.
+            (So, by implication, it's probably not supported on anything else.)
+
         Parameters:
-            rg_bits (int): (to be documented)
-            bits_per_sample (int): (to be documented)
-            count_of_samples (int): (to be documented)
+            bits (str): string of '0' and '1' characters. Its length should be (bits_per_sample * count_of_samples).
+            bits_per_sample (int): Bits per sample, should be 1, 2, 4, 8, or 16.
+            count_of_samples (int): Number of samples.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
+
+        if len(bits) != (bits_per_sample * count_of_samples):
+            raise PyDwfError("Unexpected number of bits.")
+
+        octets = []
+        while len(bits) > 0:
+            octet_str = bits[:8]
+            octet = int(octet_str[::-1], 2)
+            octets.append(octet)
+            bits = bits[8:]
+
+        # We convert the 'octets' input data to an array of ctypes unsigned chars.
+        # This silences a spurious mypy warning.
+
+        octet_ctypes_type = (ctypes.c_ubyte * len(octets))
+        octet_ctypes = octet_ctypes_type(*octets)
+
         result = self.lib.FDwfDigitalOutPlayDataSet(
             self.hdwf,
-            rg_bits,
+            octet_ctypes,
             bits_per_sample,
             count_of_samples)
         if result != RESULT_SUCCESS:
@@ -888,6 +918,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     def playRateSet(self, playback_rate: float) -> None:
         """Set the |DigitalOut| playback rate, in Hz.
 
+        Note:
+            The DWF documentation explicitly states that this function is supported by the Digital Discovery.
+            (So, by implication, it's probably not supported on anything else.)
+
         Parameters:
             playback_rate (float): The playback rate, in Hz.
 
