@@ -70,7 +70,7 @@ class DigitalUart(AbstractDwfDeviceSubApi):
                 * 1 — odd parity
                 * 2 — even parity
 
-                The most common choice is no parity (i.e., 0).
+                The most common choice is *no parity* (i.e., 0).
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -79,6 +79,24 @@ class DigitalUart(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
+    def polaritySet(self, polarity: int) -> None:
+        """Set the UART signal polarity.
+
+        Parameters:
+            parity (int): The polarity used by the receiver and transmitter:
+
+                * 0 — normal
+                * 1 — inverted
+
+                The most common choice and default polarity is *normal* (i.e., 0).
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfDigitalUartPolaritySet(self.hdwf, polarity)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
     def stopSet(self, stopbits: float) -> None:
         """Set the number of UART stop bits.
 
