@@ -1,8 +1,8 @@
-"""This module defines Python equivalents of the enum types found in the C library header file *dwf.h*.
+"""This module defines Python equivalents of the enumerations found in the C library header file *dwf.h*.
 
 Note:
-    The obsolete enum types *TRIGCOND* and *STS* that are defined in the C header file have not been defined here.
-    *TRIGCOND* has been replaced by |DwfTriggerSlope:link|; *STS* has been replaced by |DwfState.link|.
+    The obsolete enumerations *TRIGCOND* and *STS* that are defined in the C header file have not been defined here.
+    *TRIGCOND* has been replaced by |DwfTriggerSlope:link|; *STS* has been replaced by |DwfState:link|.
 """
 
 import enum
@@ -64,8 +64,7 @@ class DwfErrorCode(_FixReprMethod, enum.Enum):
     """Invalid parameter sent in API call."""
 
 
-@enum.unique
-class DwfEnumFilter(_FixReprMethod, enum.Enum):
+class DwfEnumFilter(_FixReprMethod, enum.Flag):
     """Enumeration type for device class constants, used during device enumeration.
 
     This type is used by the |DeviceEnum.enumerateDevices:link| method to constrain
@@ -77,17 +76,38 @@ class DwfEnumFilter(_FixReprMethod, enum.Enum):
     All = 0
     """Enumerate all available devices."""
 
+    Type = 0x80000000
+    """Enumerate by type (0x80000000)."""
+
+    USB = 0x00000001
+    """Enumerate USB devices."""
+
+    Network = 0x00000002
+    """Enumerate Network devices."""
+
+    AXI = 0x00000004
+    """Enumerate AXI devices (used when running on an ADP 3x50 device)."""
+
+    Remote   = 0x10000000
+    """Enumerate remote devices (0x10000000)."""
+
+    Audio = 0x20000000
+    """Enumerate audio devices (0x20000000)."""
+
+    Demo = 0x40000000
+    """Enumerate demo devices (0x40000000)."""
+
     EExplorer = 1
-    """Enumerate only Electronics Explorer devices."""
+    """Enumerate only Electronics Explorer devices. Deprecated since DWF version 3.17."""
 
     Discovery = 2
-    """Enumerate only Analog Discovery devices."""
+    """Enumerate only Analog Discovery devices. Deprecated since DWF version 3.17."""
 
     Discovery2 = 3
-    """Enumerate only Analog Discovery 2 devices."""
+    """Enumerate only Analog Discovery 2 devices. Deprecated since DWF version 3.17."""
 
     DDiscovery = 4
-    """Enumerate only Digital Discovery devices."""
+    """Enumerate only Digital Discovery devices. Deprecated since DWF version 3.17."""
 
 
 @enum.unique
@@ -100,14 +120,16 @@ class DwfEnumConfigInfo(_FixReprMethod, enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
+    #pylint: disable=line-too-long
+
     TooltipText = -1
     """Tooltip text.
 
     Maximum length: 2048 characters.
 
     Note:
-        This value is not officially documented. Its existence was revealed in a message on the Digilent forum:
-        https://forum.digilentinc.com/topic/21720-small-issue-and-questions-about-device-configurations/#comment-62717
+        This value is not officially documented. Its existence was revealed in a
+        `message on the Digilent forum <https://forum.digilentinc.com/topic/21720-small-issue-and-questions-about-device-configurations/#comment-62717>`_.
     """
 
     OtherInfoText = -2
@@ -116,8 +138,8 @@ class DwfEnumConfigInfo(_FixReprMethod, enum.Enum):
     Maximum length: 256 characters.
 
     Note:
-        This value is not officially documented. Its existence was revealed in a message on the Digilent forum:
-        https://forum.digilentinc.com/topic/21720-small-issue-and-questions-about-device-configurations/#comment-62717
+        This value is not officially documented. Its existence was revealed in a
+        `message on the Digilent forum <https://forum.digilentinc.com/topic/21720-small-issue-and-questions-about-device-configurations/#comment-62717>`_.
     """
 
     AnalogInChannelCount = 1
@@ -165,10 +187,10 @@ class DwfDeviceID(_FixReprMethod, enum.Enum):
     In the C API, this type is called 'DEVID', and it is represented as an *int*.
     """
 
-    EExplorer  = 1
+    EExplorer = 1
     """Electronics Explorer devices."""
 
-    Discovery  = 2
+    Discovery = 2
     """Analog Discovery devices."""
 
     Discovery2 = 3
@@ -177,7 +199,7 @@ class DwfDeviceID(_FixReprMethod, enum.Enum):
     DDiscovery = 4
     """Digital Discovery devices."""
 
-    ADP3X50    = 6
+    ADP3X50 = 6
     """Analog Discovery Pro devices."""
 
 
@@ -197,17 +219,17 @@ class DwfDeviceVersion(_FixReprMethod, enum.Enum):
     """
 
     EExplorerC = 2
-    """Electronics Explorer devices, revision C"""
+    """Electronics Explorer devices, revision C."""
     EExplorerE = 4
-    """Electronics Explorer devices, revision E"""
+    """Electronics Explorer devices, revision E."""
     EExplorerF = 5
-    """Electronics Explorer devices, revision F"""
+    """Electronics Explorer devices, revision F."""
     DiscoveryA = 1
-    """Discovery devices, revision A"""
+    """Discovery devices, revision A."""
     DiscoveryB = 2
-    """Discovery devices, revision B"""
+    """Discovery devices, revision B."""
     DiscoveryC = 3
-    """Discovery devices, revision C"""
+    """Discovery devices, revision C."""
 
 
 @enum.unique
@@ -224,6 +246,14 @@ class DwfDeviceParameter(_FixReprMethod, enum.Enum):
     In the C API, this type is called 'DwfParam', and it is represented as an *int*.
     """
 
+    KeepOnClose = 1
+    """Keep the device running after close.
+
+    Warning:
+
+        This value is *obsolete*. Use *OnClose* instead.
+    """
+
     UsbPower = 2
     """USB power behavior if AUX power is connected.
 
@@ -291,7 +321,30 @@ class DwfDeviceParameter(_FixReprMethod, enum.Enum):
     Todo:
         The meaning of this parameter needs to be understood.
 
-        It is some frequency, expressed in MHz.
+        It is some frequency; comments say unit is Hz.
+    """
+
+    ExtFreq = 9
+    """This parameter is undocumented.
+
+    Todo:
+        The meaning of this parameter needs to be understood.
+
+        It is some frequency; comments say unit is Hz.
+    """
+
+    ClockMode = 10
+    """This parameter is undocumented.
+
+    Todo:
+        The meaning of this parameter needs to be understood.
+
+    Possible values:
+
+    * 0 — internal.
+    * 1 — output.
+    * 2 — input.
+    * 3 — IO.
     """
 
 
@@ -404,6 +457,8 @@ class DwfTriggerSource(_FixReprMethod, enum.Enum):
     Low = 16
     """Low (undocumented)."""
 
+    Clock = 17
+    """Clock (undocumented)."""
 
 @enum.unique
 class DwfTriggerSlope(_FixReprMethod, enum.Enum):
@@ -697,7 +752,7 @@ class DwfDigitalInSampleMode(_FixReprMethod, enum.Enum):
     Simple = 0
     """Only digital samples (no noise)."""
 
-    Noise  = 1
+    Noise = 1
     """Alternate samples (noise, sample, noise, sample, …) where noise is more than one transition between two samples.
 
     This setting is available when the sample rate is less than the maximum clock frequency (i.e., the divider is
@@ -715,16 +770,16 @@ class DwfDigitalOutOutput(_FixReprMethod, enum.Enum):
     """
 
     PushPull = 0
-    """Push/Pull"""
+    """Push/Pull."""
 
     OpenDrain = 1
-    """Open Drain"""
+    """Open Drain."""
 
     OpenSource = 2
-    """Open Source"""
+    """Open Source."""
 
     ThreeState = 3
-    """Tristate (for custom and random)"""
+    """Tristate (for custom and random)."""
 
 
 @enum.unique
@@ -791,7 +846,7 @@ class DwfAnalogIO(_FixReprMethod, enum.Enum):
     """
 
     Undocumented = 0
-    """This value is returned in Analog Pro devices, when using 3.16.3 of the DWF library. That is probably a bug."""
+    """This value is returned in Analog Pro devices when using 3.16.3 of the DWF library. That is probably a bug."""
 
     Enable = 1
     """The node represent an on/off switch."""
@@ -809,7 +864,7 @@ class DwfAnalogIO(_FixReprMethod, enum.Enum):
     """The node represents a temperature."""
 
     Dmm = 6
-    """(unknown)"""
+    """The node represents a DMM (digital multimeter) value."""
 
     Range = 7
     """The node represents a range."""
@@ -823,6 +878,9 @@ class DwfAnalogIO(_FixReprMethod, enum.Enum):
     Frequency = 10
     """The node represents a frequency."""
 
+    Resistance = 11
+    """The node represents a resistance."""
+
 
 @enum.unique
 class DwfAnalogImpedance(_FixReprMethod, enum.Enum):
@@ -874,3 +932,63 @@ class DwfAnalogImpedance(_FixReprMethod, enum.Enum):
 
     Quality = 13
     """Measure quality, as a factor."""
+
+    Vrms = 14
+    """Measure Vrms, in Volts."""
+
+    Vreal = 15
+    """Measure Vreal (real part of complex voltage), in Volts."""
+
+    Vimag = 16
+    """Measure Vimag (imaginary part of complex voltage), in Volts."""
+
+    Irms = 17
+    """Measure Irms, in Amps."""
+
+    Ireal = 18
+    """Measure Ireal (real part of complex current), in Amps."""
+
+    Iimag = 19
+    """Measure Iimag (imaginary part of complex current), in Amps."""
+
+
+@enum.unique
+class DwfDmm(_FixReprMethod, enum.Enum):
+    """Enumeration type for DMM (digital multimeter) measurements.
+
+    Note:
+
+        This type is currently unused in the API. It is intended for functionality in the new ADP5250 device.
+
+    In the C API, this type is called 'DwfDmm', and it is represented as an *int*.
+    """
+
+    Resistance = 1
+    """Resistance measurement."""
+
+    Continuity = 2
+    """Continuity measurement."""
+
+    Diode = 3
+    """Diode measurement."""
+
+    DCVoltage = 4
+    """DC voltage measurement."""
+
+    ACVoltage = 5
+    """AC voltage measurement."""
+
+    DCCurrent = 6
+    """DC current measurement."""
+
+    ACCurrent = 7
+    """AC current measurement."""
+
+    DCLowCurrent = 8
+    """DC low current measurement."""
+
+    ACLowCurrent = 9
+    """AC low current measurement."""
+
+    Temperature = 10
+    """Temperature measurement."""
